@@ -1,31 +1,10 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* libvisio
- * Version: MPL 1.1 / GPLv2+ / LGPLv2+
+/*
+ * This file is part of the libvisio project.
  *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License or as specified alternatively below. You may obtain a copy of
- * the License at http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * Major Contributor(s):
- * Copyright (C) 2011 Fridrich Strba <fridrich.strba@bluewin.ch>
- * Copyright (C) 2011 Eilidh McAdam <tibbylickle@gmail.com>
- *
- *
- * All Rights Reserved.
- *
- * For minor contributions see the git repository.
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPLv2+"), or
- * the GNU Lesser General Public License Version 2 or later (the "LGPLv2+"),
- * in which case the provisions of the GPLv2+ or the LGPLv2+ are applicable
- * instead of those above.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
 #include "VSDPages.h"
@@ -68,7 +47,7 @@ void libvisio::VSDPage::append(const libvisio::VSDOutputElementList &outputEleme
   m_pageElements.append(outputElements);
 }
 
-void libvisio::VSDPage::draw(libwpg::WPGPaintInterface *painter) const
+void libvisio::VSDPage::draw(librevenge::RVNGDrawingInterface *painter) const
 {
   if (painter)
     m_pageElements.draw(painter);
@@ -89,38 +68,44 @@ void libvisio::VSDPages::addBackgroundPage(const libvisio::VSDPage &page)
   m_backgroundPages[page.m_currentPageID] = page;
 }
 
-void libvisio::VSDPages::draw(libwpg::WPGPaintInterface *painter)
+void libvisio::VSDPages::draw(librevenge::RVNGDrawingInterface *painter)
 {
   if (!painter)
     return;
+  if (m_pages.empty())
+    return;
+
+  painter->startDocument(librevenge::RVNGPropertyList());
 
   for (unsigned i = 0; i < m_pages.size(); ++i)
   {
-    WPXPropertyList pageProps;
+    librevenge::RVNGPropertyList pageProps;
     pageProps.insert("svg:width", m_pages[i].m_pageWidth);
     pageProps.insert("svg:height", m_pages[i].m_pageHeight);
     if (m_pages[i].m_pageName.len())
       pageProps.insert("draw:name", m_pages[i].m_pageName);
-    painter->startGraphics(pageProps);
+    painter->startPage(pageProps);
     _drawWithBackground(painter, m_pages[i]);
-    painter->endGraphics();
+    painter->endPage();
   }
   // Visio shows background pages in tabs after the normal pages
   for (std::map<unsigned, libvisio::VSDPage>::const_iterator iter = m_backgroundPages.begin();
        iter != m_backgroundPages.end(); ++iter)
   {
-    WPXPropertyList pageProps;
+    librevenge::RVNGPropertyList pageProps;
     pageProps.insert("svg:width", iter->second.m_pageWidth);
     pageProps.insert("svg:height", iter->second.m_pageHeight);
     if (iter->second.m_pageName.len())
       pageProps.insert("draw:name", iter->second.m_pageName);
-    painter->startGraphics(pageProps);
+    painter->startPage(pageProps);
     _drawWithBackground(painter, iter->second);
-    painter->endGraphics();
+    painter->endPage();
   }
+
+  painter->endDocument();
 }
 
-void libvisio::VSDPages::_drawWithBackground(libwpg::WPGPaintInterface *painter, const libvisio::VSDPage &page)
+void libvisio::VSDPages::_drawWithBackground(librevenge::RVNGDrawingInterface *painter, const libvisio::VSDPage &page)
 {
   if (!painter)
     return;
